==> beast-payment-api-1.1.7-20190214.091550-5-sources.jar: com/thebeastshop/payment/vo/redirect/PRedirectRequestVO.java <==
package com.thebeastshop.payment.vo.redirect;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.payment.enums.PPaymentChannelEnum;
import com.thebeastshop.payment.enums.PPaymentStatusEnum;

/**
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-11-17 15:09
 */
public class PRedirectRequestVO extends BaseDO {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private PPaymentChannelEnum channel;

	private PPaymentStatusEnum status;

	private PAliMobilePayReqVO aliMobilePayReq;

	private PAliCrossBorderMobilePayReqVO aliCrossBorderMobilePayReq;

	private PWxMobilePayReqVO wxMobilePayReq;

	private PAliDirectPayReqVO aliDirectPayReq;

	private PAliCrossBorderDirectPayReqVO aliCrossBorderDirectPayReq;

	private PAliBankPayReqVO aliBankPayReq;

	private PWxMiniProgramPayReqVO wxMiniProgramPayReq;

	private PWxOfficialAccountPayReqVO wxOfficialAccountPayReq;

	private PAliWapDirectPayReqVO aliWapDirectPayReq;

	private PAliWapCrossBorderDirectPayReqVO aliWapCrossBorderDirectPayReq;

	public PPaymentChannelEnum getChannel() {
		return channel;
	}

	public void setChannel(PPaymentChannelEnum channel) {
		this.channel = channel;
	}

	public PPaymentStatusEnum getStatus() {
		return status;
	}

	public void setStatus(PPaymentStatusEnum status) {
		this.status = status;
	}

	public PAliMobilePayReqVO getAliMobilePayReq() {
		return aliMobilePayReq;
	}

	public void setAliMobilePayReq(PAliMobilePayReqVO aliMobilePayReq) {
		this.aliMobilePayReq = aliMobilePayReq;
	}

	public PAliCrossBorderMobilePayReqVO getAliCrossBorderMobilePayReq() {
		return aliCrossBorderMobilePayReq;
	}

	public void setAliCrossBorderMobilePayReq(PAliCrossBorderMobilePayReqVO aliCrossBorderMobilePayReq) {
		this.aliCrossBorderMobilePayReq = aliCrossBorderMobilePayReq;
	}

	public PWxMobilePayReqVO getWxMobilePayReq() {
		return wxMobilePayReq;
	}

	public void setWxMobilePayReq(PWxMobilePayReqVO wxMobilePayReq) {
		this.wxMobilePayReq = wxMobilePayReq;
	}

	public PAliDirectPayReqVO getAliDirectPayReq() {
		return aliDirectPayReq;
	}

	public void setAliDirectPayReq(PAliDirectPayReqVO aliDirectPayReq) {
		this.aliDirectPayReq = aliDirectPayReq;
	}

	public PAliCrossBorderDirectPayReqVO getAliCrossBorderDirectPayReq() {
		return aliCrossBorderDirectPayReq;
	}

	public void setAliCrossBorderDirectPayReq(PAliCrossBorderDirectPayReqVO aliCrossBorderDirectPayReq) {
		this.aliCrossBorderDirectPayReq = aliCrossBorderDirectPayReq;
	}

	public PAliBankPayReqVO getAliBankPayReq() {
		return aliBankPayReq;
	}

	public void setAliBankPayReq(PAliBankPayReqVO aliBankPayReq) {
		this.aliBankPayReq = aliBankPayReq;
	}

	public PWxMiniProgramPayReqVO getWxMiniProgramPayReq() {
		return wxMiniProgramPayReq;
	}

	public void setWxMiniProgramPayReq(PWxMiniProgramPayReqVO wxMiniProgramPayReq) {
		this.wxMiniProgramPayReq = wxMiniProgramPayReq;
	}

	public PWxOfficialAccountPayReqVO getWxOfficialAccountPayReq() {
		return wxOfficialAccountPayReq;
	}

	public void setWxOfficialAccountPayReq(PWxOfficialAccountPayReqVO wxOfficialAccountPayReq) {
		this.wxOfficialAccountPayReq = wxOfficialAccountPayReq;
	}

	public PAliWapDirectPayReqVO getAliWapDirectPayReq() {
		return aliWapDirectPayReq;
	}

	public void setAliWapDirectPayReq(PAliWapDirectPayReqVO aliWapDirectPayReq) {
		this.aliWapDirectPayReq = aliWapDirectPayReq;
	}

	public PAliWapCrossBorderDirectPayReqVO getAliWapCrossBorderDirectPayReq() {
		return aliWapCrossBorderDirectPayReq;
	}

	public void setAliWapCrossBorderDirectPayReq(PAliWapCrossBorderDirectPayReqVO aliWapCrossBorderDirectPayReq) {
		this.aliWapCrossBorderDirectPayReq = aliWapCrossBorderDirectPayReq;
	}

}

==> beast-payment-api-1.3.3-20201225.074752-29-sources.jar: com/thebeastshop/payment/vo/redirect/PRedirectRequestVO.java <==
package com.thebeastshop.payment.vo.redirect;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.payment.enums.PPaymentChannelEnum;
import com.thebeastshop.payment.enums.PPaymentStatusEnum;

/**
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-11-17 15:09
 */
public class PRedirectRequestVO extends BaseDO {

	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	private PPaymentChannelEnum channel;

	private PPaymentStatusEnum status;

	private PAliMobilePayReqVO aliMobilePayReq;

	private PAliCrossBorderMobilePayReqVO aliCrossBorderMobilePayReq;

	private PWxMobilePayReqVO wxMobilePayReq;

	private PAliDirectPayReqVO aliDirectPayReq;

	private PAliCrossBorderDirectPayReqVO aliCrossBorderDirectPayReq;

	private PAliBankPayReqVO aliBankPayReq;

	private PWxMiniProgramPayReqVO wxMiniProgramPayReq;

	private PWxOfficialAccountPayReqVO wxOfficialAccountPayReq;

	private PAliWapDirectPayReqVO aliWapDirectPayReq;

	private PAliWapCrossBorderDirectPayReqVO aliWapCrossBorderDirectPayReq;

	private String aliH5RedirectUrl;

	private String pcQrCode;

	public PPaymentChannelEnum getChannel() {
		return channel;
	}

	public void setChannel(PPaymentChannelEnum channel) {
		this.channel = channel;
	}

	public PPaymentStatusEnum getStatus() {
		return status;
	}

	public void setStatus(PPaymentStatusEnum status) {
		this.status = status;
	}

	public PAliMobilePayReqVO getAliMobilePayReq() {
		return aliMobilePayReq;
	}

	public void setAliMobilePayReq(PAliMobilePayReqVO aliMobilePayReq) {
		this.aliMobilePayReq = aliMobilePayReq;
	}

	public PAliCrossBorderMobilePayReqVO getAliCrossBorderMobilePayReq() {
		return aliCrossBorderMobilePayReq;
	}

	public void setAliCrossBorderMobilePayReq(PAliCrossBorderMobilePayReqVO aliCrossBorderMobilePayReq) {
		this.aliCrossBorderMobilePayReq = aliCrossBorderMobilePayReq;
	}

	public PWxMobilePayReqVO getWxMobilePayReq() {
		return wxMobilePayReq;
	}

	public void setWxMobilePayReq(PWxMobilePayReqVO wxMobilePayReq) {
		this.wxMobilePayReq = wxMobilePayReq;
	}

	public PAliDirectPayReqVO getAliDirectPayReq() {
		return aliDirectPayReq;
	}

	public void setAliDirectPayReq(PAliDirectPayReqVO aliDirectPayReq) {
		this.aliDirectPayReq = aliDirectPayReq;
	}

	public PAliCrossBorderDirectPayReqVO getAliCrossBorderDirectPayReq() {
		return aliCrossBorderDirectPayReq;
	}

	public void setAliCrossBorderDirectPayReq(PAliCrossBorderDirectPayReqVO aliCrossBorderDirectPayReq) {
		this.aliCrossBorderDirectPayReq = aliCrossBorderDirectPayReq;
	}

	public PAliBankPayReqVO getAliBankPayReq() {
		return aliBankPayReq;
	}

	public void setAliBankPayReq(PAliBankPayReqVO aliBankPayReq) {
		this.aliBankPayReq = aliBankPayReq;
	}

	public PWxMiniProgramPayReqVO getWxMiniProgramPayReq() {
		return wxMiniProgramPayReq;
	}

	public void setWxMiniProgramPayReq(PWxMiniProgramPayReqVO wxMiniProgramPayReq) {
		this.wxMiniProgramPayReq = wxMiniProgramPayReq;
	}

	public PWxOfficialAccountPayReqVO getWxOfficialAccountPayReq() {
		return wxOfficialAccountPayReq;
	}

	public void setWxOfficialAccountPayReq(PWxOfficialAccountPayReqVO wxOfficialAccountPayReq) {
		this.wxOfficialAccountPayReq = wxOfficialAccountPayReq;
	}

	public PAliWapDirectPayReqVO getAliWapDirectPayReq() {
		return aliWapDirectPayReq;
	}

	public void setAliWapDirectPayReq(PAliWapDirectPayReqVO aliWapDirectPayReq) {
		this.aliWapDirectPayReq = aliWapDirectPayReq;
	}

	public PAliWapCrossBorderDirectPayReqVO getAliWapCrossBorderDirectPayReq() {
		return aliWapCrossBorderDirectPayReq;
	}

	public void setAliWapCrossBorderDirectPayReq(PAliWapCrossBorderDirectPayReqVO aliWapCrossBorderDirectPayReq) {
		this.aliWapCrossBorderDirectPayReq = aliWapCrossBorderDirectPayReq;
	}

	public String getAliH5RedirectUrl() {
		return aliH5RedirectUrl;
	}

	public void setAliH5RedirectUrl(String aliH5RedirectUrl) {
		this.aliH5RedirectUrl = aliH5RedirectUrl;
	}

	public String getPcQrCode() {
		return pcQrCode;
	}

	public void setPcQrCode(String pcQrCode) {
		this.pcQrCode = pcQrCode;
	}
}
